@@ -20,7 +20,7 @@ REF_BUCKET = 'gs://cpg-reference'
 NOALT_REGIONS = join(REF_BUCKET, 'noalt.bed')
 SOMALIER_SITES = join(REF_BUCKET, 'somalier/v0/sites.hg38.vcf.gz')
 
-BROAD_REF_BUCKET = f'{REF_BUCKET}/hg38/v1'
+BROAD_REF_BUCKET = f'{REF_BUCKET}/hg38/v0'
 REF_FASTA = join(BROAD_REF_BUCKET, 'Homo_sapiens_assembly38.fasta')
 UNPADDED_INTERVALS = join(BROAD_REF_BUCKET, 'hg38.even.handcurated.20k.intervals')
 
@@ -45,7 +45,7 @@ GNOMAD_HT = (
     'gs://gcp-public-data--gnomad/release/3.1/ht/genomes/gnomad.genomes.v3.1.sites.ht'
 )
 
-ANCESTRY_SITES = 'gs://cpg-reference/hg38/ancestry/v3/pca_sites_90k.ht'
+ANCESTRY_SITES = 'gs://cpg-reference/ancestry/v3-90k/pca_sites.ht'
 
 COHORT = 'az'
 
